@@ -16,9 +16,8 @@
 #'
 #' @examples
 #' library(units)
-#' gallon <- as_units('gallon')
-#' mtcars$consumption <- mtcars$mpg * with(ud_units, mi / gallon)
-#' mtcars$power <- mtcars$hp * with(ud_units, hp)
+#' mtcars$consumption <- set_units(mtcars$mpg, mi / gallon)
+#' mtcars$power <- set_units(mtcars$hp, hp)
 #'
 #' # Use units encoded into the data
 #' ggplot(mtcars) +
@@ -51,7 +50,7 @@ scale_x_unit <- function(name = waiver(), breaks = waiver(), unit = NULL,
     name = name, breaks = breaks,
     minor_breaks = minor_breaks, labels = labels, limits = limits,
     expand = expand, oob = oob, na.value = na.value, trans = trans,
-    guide = 'none', position = position, super = ScaleContinuousPositionUnit
+    guide = default_axis_guide, position = position, super = ScaleContinuousPositionUnit
   )
   sc$unit <- switch(
     class(unit),
@@ -88,7 +87,7 @@ scale_y_unit <- function(name = waiver(), breaks = waiver(), unit = NULL,
     name = name, breaks = breaks,
     minor_breaks = minor_breaks, labels = labels, limits = limits,
     expand = expand, oob = oob, na.value = na.value, trans = trans,
-    guide = 'none', position = position, super = ScaleContinuousPositionUnit
+    guide = default_axis_guide, position = position, super = ScaleContinuousPositionUnit
   )
   sc$unit <- switch(
     class(unit),
